is_storage_lvalue

Function is_storage_lvalue 

fn is_storage_lvalue(gcx: Gcx<'_>, expr: &Expr<'_>) -> bool
True if the lvalue is rooted in contract storage: a state variable or a local declared storage, which aliases contract storage.